@@ -5,6 +5,8 @@
 */
 
 #include "configureplugindialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KWindowConfig>
@@ -39,7 +41,7 @@ void ConfigurePluginDialog::initLayout(bool addSpacer)
     }
 
     mButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Help, this);
-    mButtonBox->setObjectName(QLatin1StringView("buttonBox"));
+    mButtonBox->setObjectName("buttonBox"_L1);
     layout->addWidget(mButtonBox);
     connect(mButtonBox, &QDialogButtonBox::accepted, this, &ConfigurePluginDialog::slotAccepted);
     connect(mButtonBox, &QDialogButtonBox::rejected, this, &ConfigurePluginDialog::reject);
@@ -88,7 +90,7 @@ void ConfigurePluginDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myConfigurePluginDialogGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myConfigurePluginDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
